==> mpt_cli-2.1.2-py3-none-any.whl: swo/mpt/cli/core/products/constants.py <==
ID_COLUMN_NAME = "ID"
ACTION_COLUMN_NAME = "Action"
CREATED_COLUMN_NAME = "Created"
MODIFIED_COLUMN_NAME = "Modified"
ERROR_COLUMN_NAME = "Error"

# Tabs definition
TAB_GENERAL = "General"
TAB_PARAMETERS_GROUPS = "Parameters Groups"
TAB_ITEMS_GROUPS = "Items Groups"
TAB_AGREEMENTS_PARAMETERS = "Agreements Parameters"
TAB_ITEM_PARAMETERS = "Item Parameters"
TAB_REQUEST_PARAMETERS = "Request Parameters"
TAB_SUBSCRIPTION_PARAMETERS = "Subscription Parameters"
TAB_ITEMS = "Items"
TAB_TEMPLATES = "Templates"
TAB_SETTINGS = "Settings"
REQUIRED_TABS = [
    TAB_GENERAL,
    TAB_PARAMETERS_GROUPS,
    TAB_ITEMS_GROUPS,
    TAB_AGREEMENTS_PARAMETERS,
    TAB_ITEM_PARAMETERS,
    TAB_REQUEST_PARAMETERS,
    TAB_SUBSCRIPTION_PARAMETERS,
    TAB_ITEMS,
    TAB_TEMPLATES,
    TAB_SETTINGS,
]

# General tab definition
GENERAL_PRODUCT_ID = "Product ID"
GENERAL_PRODUCT_NAME = "Product Name"
GENERAL_ACCOUNT_ID = "Account ID"
GENERAL_ACCOUNT_NAME = "Account Name"
GENERAL_EXPORT_DATE = "Export Date"
GENERAL_PRODUCT_WEBSITE = "Product Website"
GENERAL_CATALOG_DESCRIPTION = "Catalog Description"
GENERAL_PRODUCT_DESCRIPTION = "Product Description"
GENERAL_STATUS = "Status"
GENERAL_CREATED = CREATED_COLUMN_NAME
GENERAL_MODIFIED = "Modified"
GENERAL_FIELDS = [
    GENERAL_PRODUCT_ID,
    GENERAL_PRODUCT_NAME,
    GENERAL_ACCOUNT_ID,
    GENERAL_ACCOUNT_NAME,
    GENERAL_EXPORT_DATE,
    GENERAL_PRODUCT_WEBSITE,
    GENERAL_CATALOG_DESCRIPTION,
    GENERAL_PRODUCT_DESCRIPTION,
    GENERAL_STATUS,
    GENERAL_CREATED,
    GENERAL_MODIFIED,
]
GENERAL_REQUIRED_FIELDS = [
    GENERAL_PRODUCT_ID,
    GENERAL_PRODUCT_NAME,
    GENERAL_PRODUCT_WEBSITE,
    GENERAL_CATALOG_DESCRIPTION,
    GENERAL_PRODUCT_DESCRIPTION,
]
GENERAL_REQUIRED_FIELDS_WITH_VALUES = [
    GENERAL_PRODUCT_NAME,
    GENERAL_PRODUCT_WEBSITE,
]

# Parameters Groups tab definition
PARAMETERS_GROUPS_ID = ID_COLUMN_NAME
PARAMETERS_GROUPS_NAME = "Name"
PARAMETERS_GROUPS_ACTION = ACTION_COLUMN_NAME
PARAMETERS_GROUPS_LABEL = "Label"
PARAMETERS_GROUPS_DISPLAY_ORDER = "Display Order"
PARAMETERS_GROUPS_DESCRIPTION = "Description"
PARAMETERS_GROUPS_DEFAULT = "Default"
PARAMETERS_GROUPS_CREATED = "Created"
PARAMETERS_GROUPS_MODIFIED = MODIFIED_COLUMN_NAME
PARAMETERS_GROUPS_REQUIRED_FIELDS = [
    PARAMETERS_GROUPS_ID,
    PARAMETERS_GROUPS_NAME,
    PARAMETERS_GROUPS_ACTION,
    PARAMETERS_GROUPS_LABEL,
    PARAMETERS_GROUPS_DISPLAY_ORDER,
    PARAMETERS_GROUPS_DEFAULT,
]
PARAMETERS_GROUPS_FIELDS = [
    PARAMETERS_GROUPS_ID,
    PARAMETERS_GROUPS_NAME,
    PARAMETERS_GROUPS_ACTION,
    PARAMETERS_GROUPS_LABEL,
    PARAMETERS_GROUPS_DISPLAY_ORDER,
    PARAMETERS_GROUPS_DESCRIPTION,
    PARAMETERS_GROUPS_DEFAULT,
    PARAMETERS_GROUPS_CREATED,
    PARAMETERS_GROUPS_MODIFIED,
]

# Items Groups tab definition
ITEMS_GROUPS_ID = ID_COLUMN_NAME
ITEMS_GROUPS_NAME = "Name"
ITEMS_GROUPS_ACTION = ACTION_COLUMN_NAME
ITEMS_GROUPS_LABEL = "Label"
ITEMS_GROUPS_DISPLAY_ORDER = "Display Order"
ITEMS_GROUPS_DESCRIPTION = "Description"
ITEMS_GROUPS_DEFAULT = "Default"
ITEMS_GROUPS_MULTIPLE_CHOICES = "Multiple Choice"
ITEMS_GROUPS_REQUIRED = "Required"
ITEMS_GROUPS_CREATED = CREATED_COLUMN_NAME
ITEMS_GROUPS_MODIFIED = MODIFIED_COLUMN_NAME
ITEMS_GROUPS_REQUIRED_FIELDS = [
    ITEMS_GROUPS_ID,
    ITEMS_GROUPS_NAME,
    ITEMS_GROUPS_ACTION,
    ITEMS_GROUPS_LABEL,
    ITEMS_GROUPS_DISPLAY_ORDER,
    ITEMS_GROUPS_DESCRIPTION,
    ITEMS_GROUPS_DEFAULT,
    ITEMS_GROUPS_MULTIPLE_CHOICES,
    ITEMS_GROUPS_REQUIRED,
]
ITEMS_GROUPS_FIELDS = [
    ITEMS_GROUPS_ID,
    ITEMS_GROUPS_NAME,
    ITEMS_GROUPS_ACTION,
    ITEMS_GROUPS_LABEL,
    ITEMS_GROUPS_DISPLAY_ORDER,
    ITEMS_GROUPS_DESCRIPTION,
    ITEMS_GROUPS_DEFAULT,
    ITEMS_GROUPS_MULTIPLE_CHOICES,
    ITEMS_GROUPS_REQUIRED,
    ITEMS_GROUPS_CREATED,
    ITEMS_GROUPS_MODIFIED,
]

# Agreement, Item, Request, Subscription Parameters tab definition
PARAMETERS_ID = ID_COLUMN_NAME
PARAMETERS_NAME = "Name"
PARAMETERS_EXTERNALID = "ExternalId"
PARAMETERS_DESCRIPTION = "Description"
PARAMETERS_ACTION = ACTION_COLUMN_NAME
PARAMETERS_PHASE = "Phase"
PARAMETERS_TYPE = "Type"
PARAMETERS_GROUP_ID = "Group ID"
PARAMETERS_GROUP_NAME = "Group Name"
PARAMETERS_OPTIONS = "Options"
PARAMETERS_CONSTRAINTS = "Constraints"
PARAMETERS_DISPLAY_ORDER = "Display Order"
PARAMETERS_CREATED = CREATED_COLUMN_NAME
PARAMETERS_MODIFIED = MODIFIED_COLUMN_NAME
PARAMETERS_REQUIRED_FIELDS = [
    PARAMETERS_ID,
    PARAMETERS_NAME,
    PARAMETERS_EXTERNALID,
    PARAMETERS_ACTION,
    PARAMETERS_PHASE,
    PARAMETERS_TYPE,
    PARAMETERS_GROUP_ID,
    PARAMETERS_OPTIONS,
    PARAMETERS_CONSTRAINTS,
    PARAMETERS_DISPLAY_ORDER,
    PARAMETERS_DESCRIPTION,
]
PARAMETERS_FIELDS = [
    PARAMETERS_ID,
    PARAMETERS_NAME,
    PARAMETERS_EXTERNALID,
    PARAMETERS_ACTION,
    PARAMETERS_PHASE,
    PARAMETERS_TYPE,
    PARAMETERS_GROUP_ID,
    PARAMETERS_GROUP_NAME,
    PARAMETERS_OPTIONS,
    PARAMETERS_CONSTRAINTS,
    PARAMETERS_DISPLAY_ORDER,
    PARAMETERS_CREATED,
    PARAMETERS_MODIFIED,
    PARAMETERS_DESCRIPTION,
]

# Items tab definition
ITEMS_ID = ID_COLUMN_NAME
ITEMS_NAME = "Name"
ITEMS_ACTION = ACTION_COLUMN_NAME
ITEMS_VENDOR_ITEM_ID = "Vendor Item ID"
ITEMS_ERP_ITEM_ID = "ERP Item ID"
ITEMS_DESCRIPTION = "Description"
ITEMS_BILLING_FREQUENCY = "Billing Frequency"
ITEMS_COMMITMENT_TERM = "Commitment Term"
ITEMS_STATUS = "Status"
ITEMS_GROUP_ID = "Group ID"
ITEMS_GROUP_NAME = "Group Name"
ITEMS_UNIT_ID = "Unit ID"
ITEMS_UNIT_NAME = "Unit Name"
ITEMS_QUANTITY_APPLICABLE = "Quantity Applicable"
ITEMS_CREATED = CREATED_COLUMN_NAME
ITEMS_MODIFIED = MODIFIED_COLUMN_NAME
ITEMS_REQUIRED_FIELDS = [
    ITEMS_ID,
    ITEMS_NAME,
    ITEMS_ACTION,
    ITEMS_VENDOR_ITEM_ID,
    ITEMS_DESCRIPTION,
    ITEMS_BILLING_FREQUENCY,
    ITEMS_COMMITMENT_TERM,
    ITEMS_GROUP_ID,
    ITEMS_UNIT_NAME,
    ITEMS_QUANTITY_APPLICABLE,
]
ITEMS_FIELDS = [
    ITEMS_ID,
    ITEMS_NAME,
    ITEMS_ACTION,
    ITEMS_VENDOR_ITEM_ID,
    ITEMS_ERP_ITEM_ID,
    ITEMS_DESCRIPTION,
    ITEMS_BILLING_FREQUENCY,
    ITEMS_COMMITMENT_TERM,
    ITEMS_STATUS,
    ITEMS_GROUP_ID,
    ITEMS_GROUP_NAME,
    ITEMS_UNIT_ID,
    ITEMS_UNIT_NAME,
    ITEMS_QUANTITY_APPLICABLE,
    ITEMS_CREATED,
    ITEMS_MODIFIED,
]

# Templates tab definition
TEMPLATES_ID = ID_COLUMN_NAME
TEMPLATES_NAME = "Name"
TEMPLATES_ACTION = ACTION_COLUMN_NAME
TEMPLATES_TYPE = "Type"
TEMPLATES_DEFAULT = "Default"
TEMPLATES_CONTENT = "Content"
TEMPLATES_CREATED = CREATED_COLUMN_NAME
TEMPLATES_MODIFIED = MODIFIED_COLUMN_NAME
TEMPLATES_REQUIRED_FIELDS = [
    TEMPLATES_ID,
    TEMPLATES_NAME,
    TEMPLATES_ACTION,
    TEMPLATES_TYPE,
    TEMPLATES_DEFAULT,
    TEMPLATES_CONTENT,
]
TEMPLATES_FIELDS = [
    TEMPLATES_ID,
    TEMPLATES_NAME,
    TEMPLATES_ACTION,
    TEMPLATES_TYPE,
    TEMPLATES_DEFAULT,
    TEMPLATES_CONTENT,
    TEMPLATES_CREATED,
    TEMPLATES_MODIFIED,
]

# Settings tab definition
SETTINGS_SETTING = "Setting"
SETTINGS_VALUE = "Value"
SETTINGS_REQUIRED_FIELDS = [
    SETTINGS_SETTING,
    SETTINGS_VALUE,
]
SETTINGS_API_MAPPING = {
    "Change order validation (draft)": "preValidation.changeOrderDraft",
    "Item selection validation": "itemSelection",
    "Order queue changes notification": "orderQueueChanges",
    "Product ordering": "productOrdering",
    "Product requests": "productRequests.enabled",
    "Product requests. Request title": "productRequests.title",
    "Product requests. Call to action label": "productRequests.label",
    "Product request validation (draft)": "preValidation.productRequest",
    "Purchase order validation (draft)": "preValidation.purchaseOrderDraft",
    "Purchase order validation (query)": "preValidation.purchaseOrderQuery",
    "Termination order validation (draft)": "preValidation.terminationOrder",
}
SETTINGS_FIELDS = SETTINGS_REQUIRED_FIELDS


REQUIRED_FIELDS_BY_TAB = {
    TAB_GENERAL: GENERAL_REQUIRED_FIELDS,
    TAB_PARAMETERS_GROUPS: PARAMETERS_GROUPS_REQUIRED_FIELDS,
    TAB_ITEMS_GROUPS: ITEMS_GROUPS_REQUIRED_FIELDS,
    TAB_AGREEMENTS_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_ITEM_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_REQUEST_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_SUBSCRIPTION_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_ITEMS: ITEMS_REQUIRED_FIELDS,
    TAB_TEMPLATES: TEMPLATES_REQUIRED_FIELDS,
    TAB_SETTINGS: SETTINGS_REQUIRED_FIELDS,
}

REQUIRED_FIELDS_WITH_VALUES_BY_TAB = {
    TAB_GENERAL: GENERAL_REQUIRED_FIELDS_WITH_VALUES,
}

==> mpt_cli-5.0.1-py3-none-any.whl: swo/mpt/cli/core/products/constants.py <==
ID_COLUMN_NAME = "ID"
ACTION_COLUMN_NAME = "Action"
CREATED_COLUMN_NAME = "Created"
MODIFIED_COLUMN_NAME = "Modified"
ERROR_COLUMN_NAME = "Error"

# Tabs definition
TAB_GENERAL = "General"
TAB_PARAMETERS_GROUPS = "Parameters Groups"
TAB_ITEMS_GROUPS = "Items Groups"
TAB_AGREEMENT_PARAMETERS = "Agreements Parameters"
TAB_ITEM_PARAMETERS = "Item Parameters"
TAB_REQUEST_PARAMETERS = "Request Parameters"
TAB_SUBSCRIPTION_PARAMETERS = "Subscription Parameters"
TAB_ITEMS = "Items"
TAB_TEMPLATES = "Templates"
TAB_SETTINGS = "Settings"
ALL_TABS = [
    TAB_GENERAL,
    TAB_PARAMETERS_GROUPS,
    TAB_ITEMS_GROUPS,
    TAB_AGREEMENT_PARAMETERS,
    TAB_ITEM_PARAMETERS,
    TAB_REQUEST_PARAMETERS,
    TAB_SUBSCRIPTION_PARAMETERS,
    TAB_ITEMS,
    TAB_TEMPLATES,
    TAB_SETTINGS,
]
REQUIRED_TABS = [
    TAB_GENERAL,
    TAB_SETTINGS,
]


# General tab definition
GENERAL_PRODUCT_ID = "Product ID"
GENERAL_PRODUCT_NAME = "Product Name"
GENERAL_ACCOUNT_ID = "Account ID"
GENERAL_ACCOUNT_NAME = "Account Name"
GENERAL_EXPORT_DATE = "Export Date"
GENERAL_PRODUCT_WEBSITE = "Product Website"
GENERAL_CATALOG_DESCRIPTION = "Catalog Description"
GENERAL_PRODUCT_DESCRIPTION = "Product Description"
GENERAL_STATUS = "Status"
GENERAL_CREATED = CREATED_COLUMN_NAME
GENERAL_MODIFIED = "Modified"
GENERAL_FIELDS = [
    GENERAL_PRODUCT_ID,
    GENERAL_PRODUCT_NAME,
    GENERAL_ACCOUNT_ID,
    GENERAL_ACCOUNT_NAME,
    GENERAL_EXPORT_DATE,
    GENERAL_PRODUCT_WEBSITE,
    GENERAL_CATALOG_DESCRIPTION,
    GENERAL_PRODUCT_DESCRIPTION,
    GENERAL_STATUS,
    GENERAL_CREATED,
    GENERAL_MODIFIED,
]
GENERAL_REQUIRED_FIELDS = [
    GENERAL_PRODUCT_ID,
    GENERAL_PRODUCT_NAME,
    GENERAL_PRODUCT_WEBSITE,
    GENERAL_CATALOG_DESCRIPTION,
    GENERAL_PRODUCT_DESCRIPTION,
]
GENERAL_REQUIRED_FIELDS_WITH_VALUES = [
    GENERAL_PRODUCT_NAME,
    GENERAL_PRODUCT_WEBSITE,
]

# Parameters Groups tab definition
PARAMETERS_GROUPS_ID = ID_COLUMN_NAME
PARAMETERS_GROUPS_NAME = "Name"
PARAMETERS_GROUPS_ACTION = ACTION_COLUMN_NAME
PARAMETERS_GROUPS_LABEL = "Label"
PARAMETERS_GROUPS_DISPLAY_ORDER = "Display Order"
PARAMETERS_GROUPS_DESCRIPTION = "Description"
PARAMETERS_GROUPS_DEFAULT = "Default"
PARAMETERS_GROUPS_CREATED = "Created"
PARAMETERS_GROUPS_MODIFIED = MODIFIED_COLUMN_NAME
PARAMETERS_GROUPS_REQUIRED_FIELDS = [
    PARAMETERS_GROUPS_ID,
    PARAMETERS_GROUPS_NAME,
    PARAMETERS_GROUPS_ACTION,
    PARAMETERS_GROUPS_LABEL,
    PARAMETERS_GROUPS_DISPLAY_ORDER,
    PARAMETERS_GROUPS_DEFAULT,
]
PARAMETERS_GROUPS_FIELDS = [
    PARAMETERS_GROUPS_ID,
    PARAMETERS_GROUPS_NAME,
    PARAMETERS_GROUPS_ACTION,
    PARAMETERS_GROUPS_LABEL,
    PARAMETERS_GROUPS_DISPLAY_ORDER,
    PARAMETERS_GROUPS_DESCRIPTION,
    PARAMETERS_GROUPS_DEFAULT,
    PARAMETERS_GROUPS_CREATED,
    PARAMETERS_GROUPS_MODIFIED,
]

# Items Groups tab definition
ITEMS_GROUPS_ID = ID_COLUMN_NAME
ITEMS_GROUPS_NAME = "Name"
ITEMS_GROUPS_ACTION = ACTION_COLUMN_NAME
ITEMS_GROUPS_LABEL = "Label"
ITEMS_GROUPS_DISPLAY_ORDER = "Display Order"
ITEMS_GROUPS_DESCRIPTION = "Description"
ITEMS_GROUPS_DEFAULT = "Default"
ITEMS_GROUPS_MULTIPLE_CHOICES = "Multiple Choice"
ITEMS_GROUPS_REQUIRED = "Required"
ITEMS_GROUPS_CREATED = CREATED_COLUMN_NAME
ITEMS_GROUPS_MODIFIED = MODIFIED_COLUMN_NAME
ITEMS_GROUPS_REQUIRED_FIELDS = [
    ITEMS_GROUPS_ID,
    ITEMS_GROUPS_NAME,
    ITEMS_GROUPS_ACTION,
    ITEMS_GROUPS_LABEL,
    ITEMS_GROUPS_DISPLAY_ORDER,
    ITEMS_GROUPS_DESCRIPTION,
    ITEMS_GROUPS_DEFAULT,
    ITEMS_GROUPS_MULTIPLE_CHOICES,
    ITEMS_GROUPS_REQUIRED,
]
ITEMS_GROUPS_FIELDS = [
    ITEMS_GROUPS_ID,
    ITEMS_GROUPS_NAME,
    ITEMS_GROUPS_ACTION,
    ITEMS_GROUPS_LABEL,
    ITEMS_GROUPS_DISPLAY_ORDER,
    ITEMS_GROUPS_DESCRIPTION,
    ITEMS_GROUPS_DEFAULT,
    ITEMS_GROUPS_MULTIPLE_CHOICES,
    ITEMS_GROUPS_REQUIRED,
    ITEMS_GROUPS_CREATED,
    ITEMS_GROUPS_MODIFIED,
]

# Agreement, Item, Request, Subscription Parameters tab definition
PARAMETERS_ID = ID_COLUMN_NAME
PARAMETERS_NAME = "Name"
PARAMETERS_EXTERNALID = "ExternalId"
PARAMETERS_DESCRIPTION = "Description"
PARAMETERS_ACTION = ACTION_COLUMN_NAME
PARAMETERS_PHASE = "Phase"
PARAMETERS_TYPE = "Type"
PARAMETERS_GROUP_ID = "Group ID"
PARAMETERS_GROUP_NAME = "Group Name"
PARAMETERS_OPTIONS = "Options"
PARAMETERS_CONSTRAINTS = "Constraints"
PARAMETERS_DISPLAY_ORDER = "Display Order"
PARAMETERS_CREATED = CREATED_COLUMN_NAME
PARAMETERS_MODIFIED = MODIFIED_COLUMN_NAME
PARAMETERS_REQUIRED_FIELDS = [
    PARAMETERS_ID,
    PARAMETERS_NAME,
    PARAMETERS_EXTERNALID,
    PARAMETERS_ACTION,
    PARAMETERS_PHASE,
    PARAMETERS_TYPE,
    PARAMETERS_GROUP_ID,
    PARAMETERS_OPTIONS,
    PARAMETERS_CONSTRAINTS,
    PARAMETERS_DISPLAY_ORDER,
    PARAMETERS_DESCRIPTION,
]
PARAMETERS_FIELDS = [
    PARAMETERS_ID,
    PARAMETERS_NAME,
    PARAMETERS_EXTERNALID,
    PARAMETERS_ACTION,
    PARAMETERS_PHASE,
    PARAMETERS_TYPE,
    PARAMETERS_GROUP_ID,
    PARAMETERS_GROUP_NAME,
    PARAMETERS_OPTIONS,
    PARAMETERS_CONSTRAINTS,
    PARAMETERS_DISPLAY_ORDER,
    PARAMETERS_CREATED,
    PARAMETERS_MODIFIED,
    PARAMETERS_DESCRIPTION,
]

# Items tab definition
ITEMS_ID = ID_COLUMN_NAME
ITEMS_NAME = "Name"
ITEMS_ACTION = ACTION_COLUMN_NAME
ITEMS_VENDOR_ITEM_ID = "Vendor Item ID"
ITEMS_ERP_ITEM_ID = "ERP Item ID"
ITEMS_DESCRIPTION = "Description"
ITEMS_BILLING_FREQUENCY = "Billing Frequency"
ITEMS_COMMITMENT_TERM = "Commitment Term"
ITEMS_STATUS = "Status"
ITEMS_GROUP_ID = "Group ID"
ITEMS_GROUP_NAME = "Group Name"
ITEMS_UNIT_ID = "Unit ID"
ITEMS_UNIT_NAME = "Unit Name"
ITEMS_QUANTITY_APPLICABLE = "Quantity Applicable"
ITEMS_CREATED = CREATED_COLUMN_NAME
ITEMS_MODIFIED = MODIFIED_COLUMN_NAME
ITEMS_REQUIRED_FIELDS = [
    ITEMS_ID,
    ITEMS_NAME,
    ITEMS_ACTION,
    ITEMS_VENDOR_ITEM_ID,
    ITEMS_DESCRIPTION,
    ITEMS_BILLING_FREQUENCY,
    ITEMS_COMMITMENT_TERM,
    ITEMS_GROUP_ID,
    ITEMS_UNIT_NAME,
    ITEMS_QUANTITY_APPLICABLE,
]
ITEMS_FIELDS = [
    ITEMS_ID,
    ITEMS_NAME,
    ITEMS_ACTION,
    ITEMS_VENDOR_ITEM_ID,
    ITEMS_ERP_ITEM_ID,
    ITEMS_DESCRIPTION,
    ITEMS_BILLING_FREQUENCY,
    ITEMS_COMMITMENT_TERM,
    ITEMS_STATUS,
    ITEMS_GROUP_ID,
    ITEMS_GROUP_NAME,
    ITEMS_UNIT_ID,
    ITEMS_UNIT_NAME,
    ITEMS_QUANTITY_APPLICABLE,
    ITEMS_CREATED,
    ITEMS_MODIFIED,
]

# Templates tab definition
TEMPLATES_ID = ID_COLUMN_NAME
TEMPLATES_NAME = "Name"
TEMPLATES_ACTION = ACTION_COLUMN_NAME
TEMPLATES_TYPE = "Type"
TEMPLATES_DEFAULT = "Default"
TEMPLATES_CONTENT = "Content"
TEMPLATES_CREATED = CREATED_COLUMN_NAME
TEMPLATES_MODIFIED = MODIFIED_COLUMN_NAME
TEMPLATES_REQUIRED_FIELDS = [
    TEMPLATES_ID,
    TEMPLATES_NAME,
    TEMPLATES_ACTION,
    TEMPLATES_TYPE,
    TEMPLATES_DEFAULT,
    TEMPLATES_CONTENT,
]
TEMPLATES_FIELDS = [
    TEMPLATES_ID,
    TEMPLATES_NAME,
    TEMPLATES_ACTION,
    TEMPLATES_TYPE,
    TEMPLATES_DEFAULT,
    TEMPLATES_CONTENT,
    TEMPLATES_CREATED,
    TEMPLATES_MODIFIED,
]

# Settings tab definition
SETTINGS_SETTING = "Setting"
SETTINGS_VALUE = "Value"
SETTINGS_REQUIRED_FIELDS = [
    SETTINGS_SETTING,
    SETTINGS_VALUE,
]
SETTINGS_API_MAPPING = {
    "Change order validation (draft)": "preValidation.changeOrderDraft",
    "Item selection validation": "itemSelection",
    "Order queue changes notification": "orderQueueChanges",
    "Product ordering": "productOrdering",
    "Product requests": "productRequests.enabled",
    "Product requests. Request title": "productRequests.title",
    "Product requests. Call to action label": "productRequests.label",
    "Product request validation (draft)": "preValidation.productRequest",
    "Purchase order validation (draft)": "preValidation.purchaseOrderDraft",
    "Purchase order validation (query)": "preValidation.purchaseOrderQuery",
    "Termination order validation (draft)": "preValidation.terminationOrder",
}
SETTINGS_FIELDS = SETTINGS_REQUIRED_FIELDS


REQUIRED_FIELDS_BY_TAB = {
    TAB_GENERAL: GENERAL_REQUIRED_FIELDS,
    TAB_PARAMETERS_GROUPS: PARAMETERS_GROUPS_REQUIRED_FIELDS,
    TAB_ITEMS_GROUPS: ITEMS_GROUPS_REQUIRED_FIELDS,
    TAB_AGREEMENT_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_ITEM_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_REQUEST_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_SUBSCRIPTION_PARAMETERS: PARAMETERS_REQUIRED_FIELDS,
    TAB_ITEMS: ITEMS_REQUIRED_FIELDS,
    TAB_TEMPLATES: TEMPLATES_REQUIRED_FIELDS,
    TAB_SETTINGS: SETTINGS_REQUIRED_FIELDS,
}

REQUIRED_FIELDS_WITH_VALUES_BY_TAB = {
    TAB_GENERAL: GENERAL_REQUIRED_FIELDS_WITH_VALUES,
}
